# Provisioner

The provisioner is responsible for:

* Procuring equipment

* Setting up the facility

* Maintaining stock of supplies in the facility

* Minimizing hardware supply chain security risks

## Directives

* MUST maintain chain of custody for all hardware until after it's properly stored or where necessary tamper-proofed

The different procedures are ordered in chronological preference, to improve the efficiency of setting up the system.

## Procedures

The first task is to bootstrap the operator keys as they are an essential part of building a chain of trust. To achieve this, a bootstrapping ceremony can be used in order to procure hardware and generate keys in one continuous session. This ensures that the chain of custody is maintained for the hardware, and then that hardware is used to generate and seed PGP keys to smart cards, which can then be committed to the keychain repository, and used to sign tamper proofing evidence.

[Initial Bootstrapping Ceremony](./pgp-key-bootstrapping.md)

### Procedures Without Prerequisites
* [Provision Facility](./provision-facility.md)
* [Provision SD Card](./provision-sd-card.md)
* [Provision Tamper Proofing Equipment](./provision-tamper-proofing-equipment.md)
* [Provision Ceremonies Repository](./provision-ceremonies-repository.md)
* [Provision AirgapOS](./provision-airgapos.md)

### Procedures With Prerequisites
* [Procure Computer](./procure-computer.md)
    * Requires tamper proofing equipment to be available
* [Provision Air Gapped Bundle](./provision-air-gapped-bundle.md)
    * Requires operators to have PGP smart cards, tamper proofing equipment, AirgapOS SD card
* [Copy Shardfile SD Card](./copy-shardfile-sd-card.md)
    * Requires Root Entropy ceremony to be completed in order to have "Shardfile" SD cards available for copying
