# Operator - Provisioning PGP Keypair 

The initial set up requires the provisioner and operator to do all of these in a continuous session ensuring dual custody. Ensure that all participants are familiar with the sub-processes so that the ceremony can be completed in one working day.

## Requirements

* 3 individuals in order to have the flexibility for washroom breaks, fetching food and drinks etc. 

* [AirgapOS SD Card](./provision-airgapos.md)

* [Tamper Proofing Equipment](./provision-tamper-proofing-equipment.md)

* [Smart Cards](../../../../component-documents/hardware-models.md#smart-cards)

    * 2 per PGP keypair

* SD Cards: [Provisioning Guide](./provision-sd-card.md)

    * 3 per PGP keypair (for backups)

    * + 2 SD cards for Keychain SD cards

* Designated [facility](./provision-facility.md)

* Sealable plastic bag: {{ #include ../../../../component-documents/hardware-models.md:sealable-plastic-bags }}
    * For hardware procurement

## Procedure

### Procure Computer (AirgapOS Compatible) 

#### Compatible Hardware


{{ #include ../../hardware.md:computer-models }}

#### Procedure

{{ #include ../../../../component-documents/hardware-procurement-and-chain-of-custody.md:steps }}

### Ceremony 

1. Enter the designated facility with an operator and individual keys are being generated for and all required equipment

1. Lock access to the facility - there should be no inflow or outflow of people during the ceremony if avoidable. During a long ceremony as this one this may be unavoidable.

1. Gut the laptop before using it: radio cards, speakers, microphones, storage drive

1. Boot AirgapOS from verified SD card

1. Check AirgapOS hashes when it's booted

### Generating PGP Keys and Seeding Cards

Repeat these steps for each keypair:

{{ #include ../../../../component-documents/openpgp-setup.md:steps-keyfork}}

1. Do not turn off the computer as you will need to use the keys that are loaded for signing in the following section

### Signing Keys

Once the keys are generated, cross-sign all keys, for example:
```    
gpg --clearsign --default-key=<key_id_2> <key_id_1>.asc

gpg --clearsign --default-key=<key_id_1> <key_id_2>.asc
```
1. Store both public keys and both signatures on an SD card and repeat the process so that there are 2 backup SD cards.

    * Label both cards "Keychain <date>"

1. Upload these keys and signatures to the ceremonies repository after the airgapped machine is shut down.

### Air-Gapped Bundle

The following objects should be in the bundle:

* AirgapOS SD Card

* Air-gapped computer

* Keychain SD Card

#### Procedure

{{ #include ../../../../component-documents/tamper-evidence-methods.md:vsbwf-procedure-sealing}}

1. Create Air-Gapped bundle (airgapos, laptop)

1. Submit evidence to ceremonies repo
